tlslite.utils.jython_compat

Package tlslite :: Package utils :: Module jython_compat |
[show private | hide private]
[frames | no frames]

## Module tlslite.utils.jython_compat

Miscellaneous functions to mask Python/Jython differences.

Classes
`CertChainBase` |
`ReportFuncBase` |
`SelfTestBase` |

Function Summary
| `bytesToString(bytes)`
| `concatArrays(a1, a2)`
| `createByteArraySequence(seq)`
| `createByteArrayZeros(howMany)`
| `formatExceptionTrace(e)`
| `getListFromSet(set)`
| `getSHA1(s)`
| `iterSet(set)`
| `numBits(n)`
| `stringToBytes(s)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net